PyBaccarat: Class List

PyBaccarat visit the ministry of silly walks

Class List
Here are the classes, structs, unions and interfaces with brief descriptions:
[detail level 123]

▼N pybaccarat | This module is collection of classes used with playing the game Baccarat
▼N baccarat | This module is collection of classes used with playing the game Baccarat
C Game | This class plays a game of Baccarat
C Hand | This class represents a hand in the game Baccarat
C Scoreboard | TBD board0 = "big road" board1 = "big eye boy" board2 = "small road" board3 = "cockroach pig"
C Ties | This class tracks tie results
▼N baccaratsystems | This module is collection of classes used with systems for playing the game Baccarat
C BaccSys |
C Dragon | TBD
C EZDragon | Card count system for EZ-Baccarat Dragon side bet
C interactive | Play Baccarat with interactive selection of hand plays
C ValSys |
▼N playingcards | This module is collection of classes used with playing Cards
C Card | The Card class represents a single playing card
C Shoe | The Shoe class represents a playing card shoe
▼Ntests |
▼N test_card | Unit test for the Card class
C TestCard |
▼N test_hand |
C TestHand |
▼N test_scoreboard | Unit test for the Card class
C TestScoreboard |
▼N test_shoe | Unit test for the Shoe class
C TestShoe |
▼N test_ties | Unit test for the Ties class
C TestTies |